@@ -8,7 +8,7 @@ use warnings;
 # The first version that completely worked with newer versions of Specio.
 use Moose 2.1802 ();
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 1;
 
@@ -26,13 +26,13 @@ Markdent - An event-based Markdown parser toolkit
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
     use Markdent::Simple::Document;
 
-    my $parser = Markdent::Simple::Document->new();
+    my $parser = Markdent::Simple::Document->new;
     my $html   = $parser->markdown_to_html(
         title    => 'My Document',
         markdown => $markdown,
@@ -174,7 +174,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 CONTRIBUTORS
 
-=for stopwords Andrew Speer Denis Ibaev Jason McIntosh Jonas Smedegaard Polina Shubina Shlomi Fish Stefan Hornburg (Racke) Tom Hukins
+=for stopwords Andrew Speer Denis Ibaev Jason McIntosh Jonas Smedegaard Konrad Bucheli Polina Shubina Shlomi Fish Stefan Hornburg (Racke) Tom Hukins
 
 =over 4
 
@@ -196,6 +196,10 @@ Jonas Smedegaard <dr@jones.dk>
 
 =item *
 
+Konrad Bucheli <konrad.bucheli@gmx.ch>
+
+=item *
+
 Polina Shubina <925043@mai.com>
 
 =item *
@@ -214,7 +218,7 @@ Tom Hukins <tom@eborcom.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
