@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Markdent::Event::CodeBlock;
 use Markdent::Regexes qw( $BlockStart $HorizontalWS );
@@ -48,7 +48,7 @@ sub _match_fenced_code_block {
         $code,
         'code block',
         ( $lang ? [ language => $lang ] : () ),
-    ) if $self->debug();
+    ) if $self->debug;
 
     $self->_send_event(
         'CodeBlock',
@@ -76,7 +76,7 @@ Markdent::Dialect::GitHub::BlockParser - Block parser for GitHub Markdown
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 DESCRIPTION
 
@@ -105,7 +105,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
