@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Markdent::Types;
 
@@ -23,9 +23,9 @@ with(
     'Markdent::Role::EventAsText',
 );
 
-sub as_text { $_[0]->delimiter() }
+sub as_text { $_[0]->delimiter }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -43,7 +43,7 @@ Markdent::Event::EndStrong - An event for the end of a strong span
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 DESCRIPTION
 
@@ -61,7 +61,7 @@ The delimiter for the strong span.
 
 This class has the following methods:
 
-=head2 $event->as_text()
+=head2 $event->as_text
 
 Returns the event's delimiter.
 
@@ -88,7 +88,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
