@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Markdent::Types;
 use Params::ValidationCompiler qw( validation_for );
@@ -35,7 +35,7 @@ has _current_node => (
 sub start_document {
     my $self = shift;
 
-    $self->_set_current_node( $self->tree() );
+    $self->_set_current_node( $self->tree );
 }
 
 sub end_document {
@@ -56,7 +56,7 @@ sub end_document {
 
         my $header
             = Tree::Simple->new( { type => 'header', level => $level } );
-        $self->_current_node()->addChild($header);
+        $self->_current_node->addChild($header);
 
         $self->_set_current_node($header);
     }
@@ -65,14 +65,14 @@ sub end_document {
 sub end_header {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_blockquote {
     my $self = shift;
 
     my $bq = Tree::Simple->new( { type => 'blockquote' } );
-    $self->_current_node()->addChild($bq);
+    $self->_current_node->addChild($bq);
 
     $self->_set_current_node($bq);
 }
@@ -80,14 +80,14 @@ sub start_blockquote {
 sub end_blockquote {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_unordered_list {
     my $self = shift;
 
     my $bq = Tree::Simple->new( { type => 'unordered_list' } );
-    $self->_current_node()->addChild($bq);
+    $self->_current_node->addChild($bq);
 
     $self->_set_current_node($bq);
 }
@@ -95,14 +95,14 @@ sub start_unordered_list {
 sub end_unordered_list {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_ordered_list {
     my $self = shift;
 
     my $bq = Tree::Simple->new( { type => 'ordered_list' } );
-    $self->_current_node()->addChild($bq);
+    $self->_current_node->addChild($bq);
 
     $self->_set_current_node($bq);
 }
@@ -110,7 +110,7 @@ sub start_ordered_list {
 sub end_ordered_list {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 {
@@ -125,7 +125,7 @@ sub end_ordered_list {
 
         my $list_item
             = Tree::Simple->new( { type => 'list_item', bullet => $bullet } );
-        $self->_current_node()->addChild($list_item);
+        $self->_current_node->addChild($list_item);
 
         $self->_set_current_node($list_item);
     }
@@ -134,7 +134,7 @@ sub end_ordered_list {
 sub end_list_item {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 {
@@ -149,7 +149,7 @@ sub end_list_item {
 
         my $pre_node
             = Tree::Simple->new( { type => 'preformatted', text => $text } );
-        $self->_current_node()->addChild($pre_node);
+        $self->_current_node->addChild($pre_node);
     }
 }
 
@@ -177,7 +177,7 @@ sub end_list_item {
             }
         );
 
-        $self->_current_node()->addChild($code_block_node);
+        $self->_current_node->addChild($code_block_node);
     }
 }
 
@@ -185,7 +185,7 @@ sub start_paragraph {
     my $self = shift;
 
     my $para = Tree::Simple->new( { type => 'paragraph' } );
-    $self->_current_node()->addChild($para);
+    $self->_current_node->addChild($para);
 
     $self->_set_current_node($para);
 }
@@ -193,7 +193,7 @@ sub start_paragraph {
 sub end_paragraph {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 {
@@ -211,7 +211,7 @@ sub end_paragraph {
         my %p    = $validator->(@_);
 
         my $para = Tree::Simple->new( { type => 'table', %p } );
-        $self->_current_node()->addChild($para);
+        $self->_current_node->addChild($para);
 
         $self->_set_current_node($para);
     }
@@ -220,14 +220,14 @@ sub end_paragraph {
 sub end_table {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_table_header {
     my $self = shift;
 
     my $para = Tree::Simple->new( { type => 'table_header' } );
-    $self->_current_node()->addChild($para);
+    $self->_current_node->addChild($para);
 
     $self->_set_current_node($para);
 }
@@ -235,14 +235,14 @@ sub start_table_header {
 sub end_table_header {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_table_body {
     my $self = shift;
 
     my $para = Tree::Simple->new( { type => 'table_body' } );
-    $self->_current_node()->addChild($para);
+    $self->_current_node->addChild($para);
 
     $self->_set_current_node($para);
 }
@@ -250,14 +250,14 @@ sub start_table_body {
 sub end_table_body {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_table_row {
     my $self = shift;
 
     my $para = Tree::Simple->new( { type => 'table_row' } );
-    $self->_current_node()->addChild($para);
+    $self->_current_node->addChild($para);
 
     $self->_set_current_node($para);
 }
@@ -265,7 +265,7 @@ sub start_table_row {
 sub end_table_row {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 {
@@ -285,7 +285,7 @@ sub end_table_row {
         my %p    = $validator->(@_);
 
         my $para = Tree::Simple->new( { type => 'table_cell', %p } );
-        $self->_current_node()->addChild($para);
+        $self->_current_node->addChild($para);
 
         $self->_set_current_node($para);
     }
@@ -294,7 +294,7 @@ sub end_table_row {
 sub end_table_cell {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_emphasis {
@@ -306,7 +306,7 @@ sub start_emphasis {
 sub end_emphasis {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub start_strong {
@@ -318,7 +318,19 @@ sub start_strong {
 sub end_strong {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
+}
+
+sub start_strikethrough {
+    my $self = shift;
+
+    $self->_start_markup_node('strikethrough');
+}
+
+sub end_strikethrough {
+    my $self = shift;
+
+    $self->_set_current_up_one_level;
 }
 
 sub start_code {
@@ -330,7 +342,7 @@ sub start_code {
 sub end_code {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 {
@@ -348,7 +360,7 @@ sub end_code {
         my %p    = $validator->(@_);
 
         my $link_node = Tree::Simple->new( { type => 'auto_link', %p } );
-        $self->_current_node()->addChild($link_node);
+        $self->_current_node->addChild($link_node);
     }
 }
 
@@ -381,7 +393,7 @@ sub end_code {
 sub end_link {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 sub line_break {
@@ -389,7 +401,7 @@ sub line_break {
 
     my $break_node = Tree::Simple->new( { type => 'line_break' } );
 
-    $self->_current_node()->addChild($break_node);
+    $self->_current_node->addChild($break_node);
 }
 
 {
@@ -406,7 +418,7 @@ sub line_break {
 
         my $text_node
             = Tree::Simple->new( { type => 'text', text => $text } );
-        $self->_current_node()->addChild($text_node);
+        $self->_current_node->addChild($text_node);
     }
 }
 
@@ -431,7 +443,7 @@ sub line_break {
             }
         );
 
-        $self->_current_node()->addChild($tag_node);
+        $self->_current_node->addChild($tag_node);
 
         $self->_set_current_node($tag_node);
     }
@@ -440,7 +452,7 @@ sub line_break {
 sub end_html_tag {
     my $self = shift;
 
-    $self->_set_current_up_one_level();
+    $self->_set_current_up_one_level;
 }
 
 {
@@ -457,7 +469,7 @@ sub end_html_tag {
 
         my $html_node = Tree::Simple->new(
             { type => 'html_comment_block', text => $text } );
-        $self->_current_node()->addChild($html_node);
+        $self->_current_node->addChild($html_node);
     }
 }
 
@@ -475,7 +487,7 @@ sub end_html_tag {
 
         my $html_node
             = Tree::Simple->new( { type => 'html_comment', text => $text } );
-        $self->_current_node()->addChild($html_node);
+        $self->_current_node->addChild($html_node);
     }
 }
 
@@ -500,7 +512,7 @@ sub end_html_tag {
             }
         );
 
-        $self->_current_node()->addChild($tag_node);
+        $self->_current_node->addChild($tag_node);
     }
 }
 
@@ -519,7 +531,7 @@ sub end_html_tag {
         my $html_node
             = Tree::Simple->new(
             { type => 'html_entity', entity => $entity } );
-        $self->_current_node()->addChild($html_node);
+        $self->_current_node->addChild($html_node);
     }
 }
 
@@ -537,7 +549,7 @@ sub end_html_tag {
 
         my $html_node
             = Tree::Simple->new( { type => 'html_block', html => $html } );
-        $self->_current_node()->addChild($html_node);
+        $self->_current_node->addChild($html_node);
     }
 }
 
@@ -566,7 +578,7 @@ sub end_html_tag {
         my %p    = $validator->(@_);
 
         my $image_node = Tree::Simple->new( { type => 'image', %p } );
-        $self->_current_node()->addChild($image_node);
+        $self->_current_node->addChild($image_node);
     }
 }
 
@@ -574,7 +586,7 @@ sub horizontal_rule {
     my $self = shift;
 
     my $hr_node = Tree::Simple->new( { type => 'horizontal_rule' } );
-    $self->_current_node()->addChild($hr_node);
+    $self->_current_node->addChild($hr_node);
 }
 
 sub _start_markup_node {
@@ -582,7 +594,7 @@ sub _start_markup_node {
     my $type = shift;
 
     my $markup = Tree::Simple->new( { type => $type, @_ } );
-    $self->_current_node()->addChild($markup);
+    $self->_current_node->addChild($markup);
 
     $self->_set_current_node($markup);
 }
@@ -590,10 +602,10 @@ sub _start_markup_node {
 sub _set_current_up_one_level {
     my $self = shift;
 
-    $self->_set_current_node( $self->_current_node()->getParent() );
+    $self->_set_current_node( $self->_current_node->getParent() );
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -611,7 +623,7 @@ Markdent::Handler::MinimalTree - A Markdent handler which builds a tree
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 DESCRIPTION
 
@@ -628,7 +640,7 @@ This class provides the following methods:
 
 This method creates a new handler.
 
-=head2 $mhmt->tree()
+=head2 $mhmt->tree
 
 Returns the root tree for the document.
 
@@ -655,7 +667,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
