@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Scalar::Util qw( blessed );
 
@@ -16,9 +16,9 @@ sub handle_event {
     my $self  = shift;
     my $event = shift;
 
-    my $meth = $event->event_name();
+    my $meth = $event->event_name;
 
-    $self->$meth( $event->kv_pairs_for_attributes() );
+    $self->$meth( $event->kv_pairs_for_attributes );
 }
 
 1;
@@ -37,7 +37,7 @@ Markdent::Role::EventsAsMethods - Turns events into method calls
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 DESCRIPTION
 
@@ -53,8 +53,8 @@ This role provides the following methods:
 Given an object which does L<Markdent::Role::Event> role, this method makes a
 method call on C<$object> based on the event's name.
 
-The method name is the same as the value of C<< $event->event_name() >>. The
-hash reference returned by C<< $event->attributes() >> is turned into a set of
+The method name is the same as the value of C<< $event->event_name >>. The
+hash reference returned by C<< $event->attributes >> is turned into a set of
 named parameters for the method. However, any keys starting with "!" in the
 attributes will not be passed to the method.
 
@@ -62,10 +62,10 @@ So, for example, a L<Markdent::Event::StartLink> event turns into a method
 call like this:
 
   $handler->start_link(
-      uri            => $event->uri(),
+      uri            => $event->uri,
       title          => $title,                     # optional
       id             => $id,                        # optional
-      is_implicit_id => $event->is_implicit_id(),
+      is_implicit_id => $event->is_implicit_id,
   );
 
 =head1 ROLES
@@ -90,7 +90,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
