@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 use Markdent::Handler::HTMLStream::Fragment;
 use Markdent::Parser;
@@ -48,7 +48,7 @@ with 'Markdent::Role::Simple';
     }
 }
 
-__PACKAGE__->meta()->make_immutable();
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -66,13 +66,13 @@ Markdent::Simple::Fragment - Convert Markdown to an HTML Fragment
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
     use Markdent::Simple::Fragment;
 
-    my $mds  = Markdent::Simple::Fragment->new();
+    my $mds  = Markdent::Simple::Fragment->new;
     my $html = $mds->markdown_to_html(
         markdown => $markdown,
     );
@@ -85,7 +85,7 @@ This class provides a very simple interface for converting Markdown to an HTML f
 
 This class provides the following methods:
 
-=head2 Markdent::Simple::Fragment->new()
+=head2 Markdent::Simple::Fragment->new
 
 Creates a new Markdent::Simple::Fragment object.
 
@@ -128,7 +128,7 @@ Dave Rolsky <autarch@urth.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Dave Rolsky.
+This software is copyright (c) 2021 by Dave Rolsky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
